]> granicus.if.org Git - python/commitdiff
Merged revisions 69846 via svnmerge from
authorJesus Cea <jcea@jcea.es>
Thu, 2 Jul 2009 15:37:21 +0000 (15:37 +0000)
committerJesus Cea <jcea@jcea.es>
Thu, 2 Jul 2009 15:37:21 +0000 (15:37 +0000)
svn+ssh://pythondev@svn.python.org/python/trunk

........
  r69846 | mark.dickinson | 2009-02-21 21:27:01 +0100 (Sat, 21 Feb 2009) | 2 lines

  Issue #5341: Fix a variety of spelling errors.
........

52 files changed:
Demo/tkinter/matt/menu-all-types-of-entries.py
Demo/tkinter/matt/menu-simple.py
Doc/howto/webservers.rst
Doc/library/io.rst
Doc/library/pty.rst
Doc/tutorial/classes.rst
Doc/tutorial/datastructures.rst
Doc/tutorial/floatingpoint.rst
Doc/tutorial/inputoutput.rst
Doc/tutorial/stdlib.rst
Lib/bsddb/test/test_basics.py
Lib/bsddb/test/test_compat.py
Lib/bsddb/test/test_recno.py
Lib/difflib.py
Lib/distutils/tests/test_core.py
Lib/email/message.py
Lib/idlelib/AutoComplete.py
Lib/idlelib/CallTips.py
Lib/idlelib/NEWS.txt
Lib/io.py
Lib/lib-tk/Tkinter.py
Lib/lib-tk/turtle.py
Lib/optparse.py
Lib/plat-mac/bundlebuilder.py
Lib/smtpd.py
Lib/tarfile.py
Lib/test/test_calendar.py
Lib/test/test_cfgparser.py
Lib/test/test_codeccallbacks.py
Lib/test/test_cookielib.py
Lib/test/test_descrtut.py
Lib/test/test_funcattrs.py
Lib/test/test_urllib2net.py
Lib/wsgiref/headers.py
Misc/AIX-NOTES
Misc/HISTORY
Misc/NEWS
Misc/cheatsheet
Modules/_ctypes/libffi/aclocal.m4
Modules/_ctypes/libffi/configure
Modules/_ctypes/libffi/src/x86/ffi64.c
Modules/_ctypes/libffi_osx/x86/x86-ffi64.c
Modules/_sqlite/connection.c
Modules/arraymodule.c
Modules/posixmodule.c
Objects/abstract.c
Objects/listsort.txt
Objects/object.c
Objects/unicodeobject.c
PC/_winreg.c
PC/os2vacpp/makefile.omk
Tools/scripts/texi2html.py

index f4afe4a8b6257527fa9569ec6128f79342594884..69a21ca5474ea060a3cf67bc0a543230233f7c87 100644 (file)
@@ -110,12 +110,12 @@ def makeCascadeMenu():
     Cascade_button.menu.choices = Menu(Cascade_button.menu)
 
     # ...and this is a menu that cascades from that.
-    Cascade_button.menu.choices.wierdones = Menu(Cascade_button.menu.choices)
+    Cascade_button.menu.choices.weirdones = Menu(Cascade_button.menu.choices)
 
     # then you define the menus from the deepest level on up.
-    Cascade_button.menu.choices.wierdones.add_command(label='avacado')
-    Cascade_button.menu.choices.wierdones.add_command(label='belgian endive')
-    Cascade_button.menu.choices.wierdones.add_command(label='beefaroni')
+    Cascade_button.menu.choices.weirdones.add_command(label='avacado')
+    Cascade_button.menu.choices.weirdones.add_command(label='belgian endive')
+    Cascade_button.menu.choices.weirdones.add_command(label='beefaroni')
 
     # definition of the menu one level up...
     Cascade_button.menu.choices.add_command(label='Chocolate')
@@ -125,8 +125,8 @@ def makeCascadeMenu():
     Cascade_button.menu.choices.add_command(label='Rocky Road')
     Cascade_button.menu.choices.add_command(label='BubbleGum')
     Cascade_button.menu.choices.add_cascade(
-        label='Wierd Flavors',
-        menu=Cascade_button.menu.choices.wierdones)
+        label='Weird Flavors',
+        menu=Cascade_button.menu.choices.weirdones)
 
     # and finally, the definition for the top level
     Cascade_button.menu.add_cascade(label='more choices',
index 46b53642e385c7b91b340600a02227c995a44291..b71c514b6a03377e0ae2a188d69e13d0857ab98b 100644 (file)
@@ -48,7 +48,7 @@ def makeFileMenu():
     File_button.menu = Menu(File_button)
 
     # add an item. The first param is a menu entry type,
-    # must be one of: "cascade", "checkbutton", "command", "radiobutton", "seperator"
+    # must be one of: "cascade", "checkbutton", "command", "radiobutton", "separator"
     # see menu-demo-2.py for examples of use
     File_button.menu.add_command(label='New...', underline=0,
                                  command=new_file)
index 62c9124c0bf5fe7260c9f97ee8010a8f3b7ef418..4613c76de68cd7ffe113b8759935f7c85772c7a0 100644 (file)
@@ -426,7 +426,7 @@ MVC stands for three components:
   user.  Typically this component is represented by the templates.
 * The *controller*.  This is the layer between the user and the model.  The
   controller reacts on user actions (like opening some specific URL) and tells
-  the model to modify the data if neccessary.
+  the model to modify the data if necessary.
 
 While one might think that MVC is a complex design pattern, in fact it is not.
 It is used in Python because it has turned out to be useful for creating clean,
@@ -435,9 +435,9 @@ maintainable web sites.
 .. note::
 
    While not all Python frameworks explicitly support MVC, it is often trivial
-   to create a web site which uses the MVC pattern by seperating the data logic
+   to create a web site which uses the MVC pattern by separating the data logic
    (the model) from the user interaction logic (the controller) and the
-   templates (the view).  That's why it is important not to write unneccessary
+   templates (the view).  That's why it is important not to write unnecessary
    Python code in the templates -- it is against MVC and creates more chaos.
 
 .. seealso::
@@ -607,7 +607,7 @@ Some notable frameworks
 -----------------------
 
 There is an incredible number of frameworks, so there is no way to describe them
-all.  It is not even neccessary, as most of these frameworks are nothing special
+all.  It is not even necessary, as most of these frameworks are nothing special
 and everything that can be done with these can also be done with one of the
 popular ones.
 
@@ -679,7 +679,7 @@ project called `Grok <http://grok.zope.org/>`_ which makes it possible for
 Another framework that's already been mentioned is `Pylons`_.  Pylons is much
 like TurboGears with ab even stronger emphasis on flexibility, which is bought
 at the cost of being more difficult to use.  Nearly every component can be
-exchanged, which makes it neccessary to use the documentation of every single
+exchanged, which makes it necessary to use the documentation of every single
 component, because there are so many Pylons combinations possible that can
 satisfy every requirement.  Pylons builds upon `Paste
 <http://pythonpaste.org/>`_, an extensive set of tools which are handy for WSGI.
index 9e870b1cc05284da48695a50b1cd62c1e8b1e72a..cccbb265edf8c4da1cfd6d789e88e4cd5983b4b4 100644 (file)
@@ -14,7 +14,7 @@ builtin :func:`open` function is defined in this module.
 
 At the top of the I/O hierarchy is the abstract base class :class:`IOBase`.  It
 defines the basic interface to a stream.  Note, however, that there is no
-seperation between reading and writing to streams; implementations are allowed
+separation between reading and writing to streams; implementations are allowed
 to throw an :exc:`IOError` if they do not support a given operation.
 
 Extending :class:`IOBase` is :class:`RawIOBase` which deals simply with the
@@ -612,7 +612,7 @@ Text I/O
    is enabled.  With this enabled, on input, the lines endings ``'\n'``,
    ``'\r'``, or ``'\r\n'`` are translated to ``'\n'`` before being returned to
    the caller.  Conversely, on output, ``'\n'`` is translated to the system
-   default line seperator, :data:`os.linesep`.  If *newline* is any other of its
+   default line separator, :data:`os.linesep`.  If *newline* is any other of its
    legal values, that newline becomes the newline when the file is read and it
    is returned untranslated.  On output, ``'\n'`` is converted to the *newline*.
 
index ec1c75f22a095f62a76370abcf608956ba809469..6579ef0c53a8708044f697a8702138ee38366341 100644 (file)
@@ -13,7 +13,7 @@ The :mod:`pty` module defines operations for handling the pseudo-terminal
 concept: starting another process and being able to write to and read from its
 controlling terminal programmatically.
 
-Because pseudo-terminal handling is highly platform dependant, there is code to
+Because pseudo-terminal handling is highly platform dependent, there is code to
 do it only for SGI and Linux. (The Linux code is supposed to work on other
 platforms, but hasn't been tested yet.)
 
index 48c7bcb9acd18928beb67d8cb9012579b612a2bc..939126e52500183e55f5b0a06e864cfedeb9d525 100644 (file)
@@ -470,7 +470,7 @@ arguments)``.  This is occasionally useful to clients as well.  (Note that this
 only works if the base class is defined or imported directly in the global
 scope.)
 
-Python has two builtin functions that work with inheritance:
+Python has two built-in functions that work with inheritance:
 
 * Use :func:`isinstance` to check an object's type: ``isinstance(obj, int)``
   will be ``True`` only if ``obj.__class__`` is :class:`int` or some class
index 047ae36368f68b03af3790faff56b158e3dec266..a56fd2b042af9c7ca8c79ef5539ca8451807abdd 100644 (file)
@@ -308,7 +308,7 @@ A more verbose version of this snippet shows the flow explicitly::
             print row[i],
         print
 
-In real world, you should prefer builtin functions to complex flow statements.
+In real world, you should prefer built-in functions to complex flow statements.
 The :func:`zip` function would do a great job for this use case::
 
     >>> zip(*mat)
index 6913c46b796a12df22049c479ab928990c4970d0..6ff2160217047920bb7ff1ca15d361bd504aeb0e 100644 (file)
@@ -65,7 +65,7 @@ display ::
    >>> 0.1
    0.1000000000000000055511151231257827021181583404541015625
 
-instead!  The Python prompt uses the builtin :func:`repr` function to obtain a
+instead!  The Python prompt uses the built-in :func:`repr` function to obtain a
 string version of everything it displays.  For floats, ``repr(float)`` rounds
 the true decimal value to 17 significant digits, giving ::
 
@@ -81,7 +81,7 @@ thing in all languages that support your hardware's floating-point arithmetic
 (although some languages may not *display* the difference by default, or in all
 output modes).
 
-Python's builtin :func:`str` function produces only 12 significant digits, and
+Python's built-in :func:`str` function produces only 12 significant digits, and
 you may wish to use that instead.  It's unusual for ``eval(str(x))`` to
 reproduce *x*, but the output may be more pleasant to look at::
 
index 34d984a5471ea98495c7ca161e2e46be2611f435..b1bc522b187794b829ddc5f549f75bd5ab2309b9 100644 (file)
@@ -187,7 +187,7 @@ notation.::
 This is particularly useful in combination with the new built-in :func:`vars`
 function, which returns a dictionary containing all local variables.
 
-For a complete overview of string formating with :meth:`str.format`, see
+For a complete overview of string formatting with :meth:`str.format`, see
 :ref:`formatstrings`.
 
 
index 8cd5d0a10a450906ac0a186c4d2a34c0167aad54..c0c7da38367db60f454ed602922cb9188fc631db 100644 (file)
@@ -21,12 +21,12 @@ operating system::
    >>> os.chdir('/server/accesslogs')
 
 Be sure to use the ``import os`` style instead of ``from os import *``.  This
-will keep :func:`os.open` from shadowing the builtin :func:`open` function which
+will keep :func:`os.open` from shadowing the built-in :func:`open` function which
 operates much differently.
 
 .. index:: builtin: help
 
-The builtin :func:`dir` and :func:`help` functions are useful as interactive
+The built-in :func:`dir` and :func:`help` functions are useful as interactive
 aids for working with large modules like :mod:`os`::
 
    >>> import os
index 52de8692a823126b0a63d2c4ef76f9a4d0991e42..0be76dbb5fd68063336542234e2cb009ba87fc7c 100644 (file)
@@ -131,7 +131,7 @@ class BasicTestCase(unittest.TestCase):
 
         self.assertEqual(d.get('0321'), '0321-0321-0321-0321-0321')
 
-        # By default non-existant keys return None...
+        # By default non-existent keys return None...
         self.assertEqual(d.get('abcd'), None)
 
         # ...but they raise exceptions in other situations.  Call
index a3b4eefbf045d3c91eda7a192fee0be3ab7fceec..0b0fa7069561e00f8a3bbf099102f00e8fafb3c7 100644 (file)
@@ -133,7 +133,7 @@ class CompatibilityTestCase(unittest.TestCase):
             except KeyError:
                 pass
             else:
-                self.fail("set_location on non-existant key did not raise KeyError")
+                self.fail("set_location on non-existent key did not raise KeyError")
 
         f.sync()
         f.close()
index b5df68bfddff9ae5f5788b5c868daf4ff56b53a3..895be8a6d058bdb6aeec784e0ef8199824a7aa40 100644 (file)
@@ -150,7 +150,7 @@ class SimpleRecnoTestCase(unittest.TestCase):
         if verbose:
             print rec
 
-        # test that non-existant key lookups work (and that
+        # test that non-existent key lookups work (and that
         # DBC_set_range doesn't have a memleak under valgrind)
         rec = c.set_range(999999)
         self.assertEqual(rec, None)
index 7498e6f095d37e7eb62fbd490604597a5b0c80e0..679bd2a01a1981f43cce91a9a1385fe3f70183e8 100644 (file)
@@ -1329,7 +1329,7 @@ def _mdiff(fromlines, tolines, context=None, linejunk=None,
     (from line tuple, to line tuple, boolean flag)
 
     from/to line tuple -- (line num, line text)
-        line num -- integer or None (to indicate a context seperation)
+        line num -- integer or None (to indicate a context separation)
         line text -- original line text with following markers inserted:
             '\0+' -- marks start of added text
             '\0-' -- marks start of deleted text
index 55d2d5df7e55d8484fad38cd582bd4abd784f8f6..e481e8de39a7fda907571ab7ce627410499ee559 100644 (file)
@@ -57,7 +57,7 @@ class CoreTestCase(unittest.TestCase):
 
     def test_run_setup_uses_current_dir(self):
         # This tests that the setup script is run with the current directory
-        # as it's own current directory; this was temporarily broken by a
+        # as its own current directory; this was temporarily broken by a
         # previous patch when TESTFN did not use the current directory.
         sys.stdout = StringIO.StringIO()
         cwd = os.getcwd()
index e44217b2b013ba2b5f084bf92a443d57b963b972..23cedf6143a71b5ec4c94c6baa9fd9207f77ca31 100644 (file)
@@ -20,7 +20,7 @@ from email import errors
 SEMISPACE = '; '
 
 # Regular expression that matches `special' characters in parameters, the
-# existance of which force quoting of the parameter value.
+# existence of which force quoting of the parameter value.
 tspecials = re.compile(r'[ \(\)<>@,;:\\"/\[\]\?=]')
 
 
index 1c74d2ebd0c64a67f2c623cdcc28dd2d6657d423..d55b799256a48809a29aaf70fcbf1ff8d88b94ef 100644 (file)
@@ -67,7 +67,7 @@ class AutoComplete:
 
     def try_open_completions_event(self, event):
         """Happens when it would be nice to open a completion list, but not
-        really neccesary, for example after an dot, so function
+        really necessary, for example after an dot, so function
         calls won't be made.
         """
         lastchar = self.text.get("insert-1c")
@@ -79,7 +79,7 @@ class AutoComplete:
                                          COMPLETE_FILES)
 
     def autocomplete_event(self, event):
-        """Happens when the user wants to complete his word, and if neccesary,
+        """Happens when the user wants to complete his word, and if necessary,
         open a completion list after that (if there is more than one
         completion)
         """
index 7bcc1e26959f284c8ec155c6b2392916925135e1..bd51b7f6a55a5165fbf1bad056ef731a4e7d61f9 100644 (file)
@@ -51,7 +51,7 @@ class CallTips:
 
     def try_open_calltip_event(self, event):
         """Happens when it would be nice to open a CallTip, but not really
-        neccesary, for example after an opening bracket, so function calls
+        necessary, for example after an opening bracket, so function calls
         won't be made.
         """
         self.open_calltip(False)
index 297dd31b05fee3028f022c6c4e54fcec4128c50f..96a138b94183fb0f40dc7e9d1f0450c5e6e8f143 100644 (file)
@@ -310,7 +310,7 @@ What's New in IDLE 1.1a3?
   window raising, especially in the Windows menu and in the debugger.
   IDLEfork 763524.
 
-- If user passes a non-existant filename on the commandline, just
+- If user passes a non-existent filename on the commandline, just
   open a new file, don't raise a dialog.  IDLEfork 854928.
 
 
index 72f7d8c5eadb9d7fa7b781988e503863fce260b2..03c867638f4170602578f335acc7ae58a9f56920 100644 (file)
--- a/Misc/NEWS
+++ b/Misc/NEWS
@@ -1087,7 +1087,7 @@ Library
 - Issue #3575: Incremental decoder's decode function now takes bytearray
   by using 's*' instead of 't#'.
 
-- Issue #2222: Fixed reference leak when occured os.rename()
+- Issue #2222: Fixed reference leak when occurred os.rename()
   fails unicode conversion on 2nd parameter. (windows only)
 
 - Issue 2464. urllib2 now supports a malformation in the URL received
index cb0702ab1e448dd5429e5796f11d32137a59be76..df69f244f68d5117799e13450f575cfa314fb7cf 100644 (file)
@@ -481,7 +481,7 @@ s.istitle()       return True if string s is a titlecased string, False    (7)
 s.isupper()       return True if all characters in s are uppercase, False  (6)
                   otherwise.
 s.join(seq)       return a concatenation of the strings in the sequence
-                  seq, seperated by 's's.
+                  seq, separated by 's's.
 s.ljust(width)    return s left justified in a string of length width.    (1),
                                                                            (8)
 s.lower()         return a copy of s converted to lowercase.
@@ -1556,10 +1556,10 @@ secs)         monday), Julian day(1-366), daylight flag(-1,0 or 1))
 asctime(
 timeTuple),
 strftime(
-format,       return a formated string representing time.
+format,       return a formatted string representing time.
 timeTuple)
 mktime(tuple) inverse of localtime(). Return a float.
-strptime(     parse a formated string representing time, return tuple as in
+strptime(     parse a formatted string representing time, return tuple as in
 string[,      gmtime().
 format])
 sleep(secs)   Suspend execution for <secs> seconds. <secs> can be a float.
index e9279287fb7193cc2ea5b95150114699478b2637..6b38324ec34aa12cbfbdf94b9ec901fa4068b3e1 100644 (file)
@@ -1155,7 +1155,7 @@ if test -n "$_LT_AC_TAGVAR(hardcode_libdir_flag_spec, $1)" || \
    test -n "$_LT_AC_TAGVAR(runpath_var, $1)" || \
    test "X$_LT_AC_TAGVAR(hardcode_automatic, $1)" = "Xyes" ; then
 
-  # We can hardcode non-existant directories.
+  # We can hardcode non-existent directories.
   if test "$_LT_AC_TAGVAR(hardcode_direct, $1)" != no &&
      # If the only mechanism to avoid hardcoding is shlibpath_var, we
      # have to relink, otherwise we might link with an installed library
index 2034a1af36f0ae7739d049b1a97a5821abb7b8cd..6984fc67fbc462ba7f77f773403922ff0f14e686 100755 (executable)
@@ -9546,7 +9546,7 @@ if test -n "$hardcode_libdir_flag_spec" || \
    test -n "$runpath_var" || \
    test "X$hardcode_automatic" = "Xyes" ; then
 
-  # We can hardcode non-existant directories.
+  # We can hardcode non-existent directories.
   if test "$hardcode_direct" != no &&
      # If the only mechanism to avoid hardcoding is shlibpath_var, we
      # have to relink, otherwise we might link with an installed library
@@ -13514,7 +13514,7 @@ if test -n "$hardcode_libdir_flag_spec_CXX" || \
    test -n "$runpath_var_CXX" || \
    test "X$hardcode_automatic_CXX" = "Xyes" ; then
 
-  # We can hardcode non-existant directories.
+  # We can hardcode non-existent directories.
   if test "$hardcode_direct_CXX" != no &&
      # If the only mechanism to avoid hardcoding is shlibpath_var, we
      # have to relink, otherwise we might link with an installed library
@@ -16117,7 +16117,7 @@ if test -n "$hardcode_libdir_flag_spec_F77" || \
    test -n "$runpath_var_F77" || \
    test "X$hardcode_automatic_F77" = "Xyes" ; then
 
-  # We can hardcode non-existant directories.
+  # We can hardcode non-existent directories.
   if test "$hardcode_direct_F77" != no &&
      # If the only mechanism to avoid hardcoding is shlibpath_var, we
      # have to relink, otherwise we might link with an installed library
@@ -18720,7 +18720,7 @@ if test -n "$hardcode_libdir_flag_spec_GCJ" || \
    test -n "$runpath_var_GCJ" || \
    test "X$hardcode_automatic_GCJ" = "Xyes" ; then
 
-  # We can hardcode non-existant directories.
+  # We can hardcode non-existent directories.
   if test "$hardcode_direct_GCJ" != no &&
      # If the only mechanism to avoid hardcoding is shlibpath_var, we
      # have to relink, otherwise we might link with an installed library
index 2896ae4c53f1af727f28178bbeb54b84bbbdc80a..fa992552ca18df54ba35a3d732d10a753eca443a 100644 (file)
@@ -52,7 +52,7 @@ extern void ffi_call_unix64 (void *args, unsigned long bytes, unsigned flags,
 /* Register class used for passing given 64bit part of the argument.
    These represent classes as documented by the PS ABI, with the exception
    of SSESF, SSEDF classes, that are basically SSE class, just gcc will
-   use SF or DFmode move instead of DImode to avoid reformating penalties.
+   use SF or DFmode move instead of DImode to avoid reformatting penalties.
 
    Similary we play games with INTEGERSI_CLASS to use cheaper SImode moves
    whenever possible (upper half does contain padding).  */
index ac37fb7929789a41fbe500da07e6df546a2f50f4..a262ed09a65d2dfbae4e2a62ac38685960711e6e 100644 (file)
@@ -55,7 +55,7 @@ ffi_call_unix64(
 /*     Register class used for passing given 64bit part of the argument.
        These represent classes as documented by the PS ABI, with the exception
        of SSESF, SSEDF classes, that are basically SSE class, just gcc will
-       use SF or DFmode move instead of DImode to avoid reformating penalties.
+       use SF or DFmode move instead of DImode to avoid reformatting penalties.
 
        Similary we play games with INTEGERSI_CLASS to use cheaper SImode moves
        whenever possible (upper half does contain padding).  */
index 8aa0882450319cccf0590889d9520283cd3a5463..74177910baa8464a4d59211a88ca9bffdce98590 100644 (file)
@@ -864,7 +864,7 @@ static int _progress_handler(void* user_arg)
             PyErr_Clear();
         }
 
-        /* abort query if error occured */
+        /* abort query if error occurred */
         rc = 1; 
     } else {
         rc = (int)PyObject_IsTrue(ret);
index bcd82aa977a72fcfff0a8af2d9fc22d621e793fb..6fad71c8a6a31a473a572d312b12f648bcdb3e7e 100644 (file)
@@ -935,7 +935,7 @@ array_count(arrayobject *self, PyObject *v)
 PyDoc_STRVAR(count_doc,
 "count(x)\n\
 \n\
-Return number of occurences of x in the array.");
+Return number of occurrences of x in the array.");
 
 static PyObject *
 array_index(arrayobject *self, PyObject *v)
@@ -959,7 +959,7 @@ array_index(arrayobject *self, PyObject *v)
 PyDoc_STRVAR(index_doc,
 "index(x)\n\
 \n\
-Return index of first occurence of x in the array.");
+Return index of first occurrence of x in the array.");
 
 static int
 array_contains(arrayobject *self, PyObject *v)
@@ -1001,7 +1001,7 @@ array_remove(arrayobject *self, PyObject *v)
 PyDoc_STRVAR(remove_doc,
 "remove(x)\n\
 \n\
-Remove the first occurence of x in the array.");
+Remove the first occurrence of x in the array.");
 
 static PyObject *
 array_pop(arrayobject *self, PyObject *args)
@@ -2055,16 +2055,16 @@ Methods:\n\
 append() -- append a new item to the end of the array\n\
 buffer_info() -- return information giving the current memory info\n\
 byteswap() -- byteswap all the items of the array\n\
-count() -- return number of occurences of an object\n\
+count() -- return number of occurrences of an object\n\
 extend() -- extend array by appending multiple elements from an iterable\n\
 fromfile() -- read items from a file object\n\
 fromlist() -- append items from the list\n\
 fromstring() -- append items from the string\n\
-index() -- return index of first occurence of an object\n\
+index() -- return index of first occurrence of an object\n\
 insert() -- insert a new item into the array at a provided position\n\
 pop() -- remove and return item (default last)\n\
 read() -- DEPRECATED, use fromfile()\n\
-remove() -- remove first occurence of an object\n\
+remove() -- remove first occurrence of an object\n\
 reverse() -- reverse the order of the items in the array\n\
 tofile() -- write all items to a file object\n\
 tolist() -- return the array converted to an ordinary list\n\
index eb8083f0eda53561e5ae6fd02c689d26ca40750e..3fd081d90ebaa68f0cbd5b626796123457cc53ec 100644 (file)
@@ -2400,7 +2400,7 @@ posix_listdir(PyObject *self, PyObject *args)
 static PyObject *
 posix__getfullpathname(PyObject *self, PyObject *args)
 {
-       /* assume encoded strings wont more than double no of chars */
+       /* assume encoded strings won't more than double no of chars */
        char inbuf[MAX_PATH*2];
        char *inbufp = inbuf;
        Py_ssize_t insize = sizeof(inbuf);
@@ -5034,7 +5034,7 @@ _PyPopenCreateProcess(char *cmdstring,
                           "Your program accessed mem currently in use at xxx"
                           and a hopeful warning about the stability of your
                           system.
-                          Cost is Ctrl+C wont kill children, but anyone
+                          Cost is Ctrl+C won't kill children, but anyone
                           who cares can have a go!
                        */
                        dwProcessFlags |= CREATE_NEW_CONSOLE;
index de8682a8ab4f7640ba96440345c22d276ed1bda2..22a72e1b87a714ccdc27a68328b5644318bd11fc 100644 (file)
@@ -2244,7 +2244,7 @@ PySequence_Fast(PyObject *v, const char *m)
 
 /* Iterate over seq.  Result depends on the operation:
    PY_ITERSEARCH_COUNT:  -1 if error, else # of times obj appears in seq.
-   PY_ITERSEARCH_INDEX:  0-based index of first occurence of obj in seq;
+   PY_ITERSEARCH_INDEX:  0-based index of first occurrence of obj in seq;
        set ValueError and return -1 if none found; also return -1 on error.
    Py_ITERSEARCH_CONTAINS:  return 1 if obj in seq, else 0; -1 on error.
 */
index 92269840e778c785de005fc90c6fdd49043837f5..31a5445c0e3d3b107890d7f12da8f913222962f7 100644 (file)
@@ -309,7 +309,7 @@ Stability constrains permissible merging patterns.  For example, if we have
     A:10000  B:20000  C:10000
 
 we dare not merge A with C first, because if A, B and C happen to contain
-a common element, it would get out of order wrt its occurence(s) in B.  The
+a common element, it would get out of order wrt its occurrence(s) in B.  The
 merging must be done as (A+B)+C or A+(B+C) instead.
 
 So merging is always done on two consecutive runs at a time, and in-place,
index 1d98efebcb60589afe45e7ac7638f2cc85b695b5..bb3693b64320d638d947687bced2ace7006d8ae9 100644 (file)
@@ -1960,7 +1960,7 @@ static void
 none_dealloc(PyObject* ignore)
 {
        /* This should never get called, but we also don't want to SEGV if
-        * we accidently decref None out of existance.
+        * we accidentally decref None out of existence.
         */
        Py_FatalError("deallocating None");
 }
index 8ffe8ce568b5901c2343ca7c4a686bf8714572f0..69110583e535183136ef8c945b898e800380a5ae 100644 (file)
@@ -1688,7 +1688,7 @@ PyObject *PyUnicode_EncodeUTF7(const Py_UNICODE *s,
                 charsleft = (charsleft << 16) | ch;
                 /* out, charsleft, bitsleft = */ ENCODE(out, charsleft, bitsleft);
 
-                /* If the next character is special then we dont' need to terminate
+                /* If the next character is special then we don't need to terminate
                    the shift sequence. If the next character is not a BASE64 character
                    or '-' then the shift sequence will be terminated implicitly and we
                    don't have to insert a '-'. */
index 74d33437bc802f65f626e094caca569314867017..e9735b22cdc451028b538f3026d4458b04570fec 100644 (file)
@@ -25,7 +25,7 @@ static char errNotAHandle[] = "Object is not a handle";
 
 /* The win32api module reports the function name that failed,
    but this concept is not in the Python core.
-   Hopefully it will one day, and in the meantime I dont
+   Hopefully it will one day, and in the meantime I don't
    want to lose this info...
 */
 #define PyErr_SetFromWindowsErrWithFunction(rc, fnname) \
@@ -694,9 +694,9 @@ PyWinObject_CloseHKEY(PyObject *obHandle)
 ** Note that fixupMultiSZ and countString have both had changes
 ** made to support "incorrect strings".  The registry specification
 ** calls for strings to be terminated with 2 null bytes.  It seems
-** some commercial packages install strings which dont conform,
+** some commercial packages install strings which don't conform,
 ** causing this code to fail - however, "regedit" etc still work
-** with these strings (ie only we dont!).
+** with these strings (ie only we don't!).
 */
 static void
 fixupMultiSZ(char **str, char *data, int len)
index 95823385ee73c8de60b53fd4c29415fdc66a908d..b03725ac24cd62dca52869a378043123d8997835 100644 (file)
@@ -220,7 +220,7 @@ MODULES             =                   \
 
   # zlibmodule.c    -- Wrapper of ZLib Compression API (GZip Format)
   # puremodule.c    -- Wrapper of Purify Debugging API (Probably Non-OS/2)
-  # dlmodule.c      -- Some Wierd Form of Data Processing Module
+  # dlmodule.c      -- Some Weird Form of Data Processing Module
   # xxmodule.c      -- Template to Create Your Own Module
 
 #
index 3ecaee68fef9dc8df359daa8ad39f8ffb9ef1cf1..57db166df1e11db749c742762cc98c809947cb5c 100755 (executable)
@@ -38,7 +38,7 @@
 # rpyron 2002-05-07
 # Robert Pyron <rpyron@alum.mit.edu>
 # 1. BUGFIX: In function makefile(), strip blanks from the nodename.
-#    This is necesary to match the behavior of parser.makeref() and
+#    This is necessary to match the behavior of parser.makeref() and
 #    parser.do_node().
 # 2. BUGFIX fixed KeyError in end_ifset (well, I may have just made
 #    it go away, rather than fix it)
--- a/Lib/io.py
+++ b/Lib/io.py
@@ -4,7 +4,7 @@ builtin open function is defined in this module.
 
 At the top of the I/O hierarchy is the abstract base class IOBase. It
 defines the basic interface to a stream. Note, however, that there is no
-seperation between reading and writing to streams; implementations are
+separation between reading and writing to streams; implementations are
 allowed to throw an IOError if they do not support a given operation.
 
 Extending IOBase is RawIOBase which deals simply with the reading and
@@ -1374,7 +1374,7 @@ class TextIOWrapper(TextIOBase):
     enabled.  With this enabled, on input, the lines endings '\n', '\r',
     or '\r\n' are translated to '\n' before being returned to the
     caller. Conversely, on output, '\n' is translated to the system
default line seperator, os.linesep. If newline is any other of its
     legal values, that newline becomes the newline when the file is read
     and it is returned untranslated. On output, '\n' is converted to the
     newline.
index 825e58dd2bd0fd980c18c66796d109d992dce985..3cce276e0aaa044ee345b41689778f640deadb33 100644 (file)
@@ -3316,7 +3316,7 @@ class PhotoImage(Image):
         """Return the color (red, green, blue) of the pixel at X,Y."""
         return self.tk.call(self.name, 'get', x, y)
     def put(self, data, to=None):
-        """Put row formated colors to image starting from
+        """Put row formatted colors to image starting from
         position TO, e.g. image.put("{red green} {blue yellow}", to=(4,6))"""
         args = (self.name, 'put', data)
         if to:
index 7bce6f6cbe3a49fed0e44b4815d00c849f75a55f..a3dc8523169acd63630c8979e6f4e8d76b6f858c 100644 (file)
@@ -2794,7 +2794,7 @@ class RawTurtle(TPen, TNavigator):
 
     def _drawturtle(self):
         """Manages the correct rendering of the turtle with respect to
-        its shape, resizemode, strech and tilt etc."""
+        its shape, resizemode, stretch and tilt etc."""
         screen = self.screen
         shape = screen._shapes[self.turtle.shapeIndex]
         ttype = shape._type
index 53bdef0ddc98494de269429f86632817e8200e06..d0d59616f30b79eb2aa9e2065e7e63693f5e87e2 100644 (file)
@@ -1588,7 +1588,7 @@ class OptionParser (OptionContainer):
         """print_usage(file : file = stdout)
 
         Print the usage message for the current program (self.usage) to
-        'file' (default stdout).  Any occurence of the string "%prog" in
+        'file' (default stdout).  Any occurrence of the string "%prog" in
         self.usage is replaced with the name of the current program
         (basename of sys.argv[0]).  Does nothing if self.usage is empty
         or not defined.
@@ -1606,7 +1606,7 @@ class OptionParser (OptionContainer):
         """print_version(file : file = stdout)
 
         Print the version message for this program (self.version) to
-        'file' (default stdout).  As with print_usage(), any occurence
+        'file' (default stdout).  As with print_usage(), any occurrence
         of "%prog" in self.version is replaced by the current program's
         name.  Does nothing if self.version is empty or undefined.
         """
index f0c7fc2b192decab3752e8dde1faac5d0c3b282a..dda95108a29cc28609b43d7ec853e6505bda8eb9 100755 (executable)
@@ -661,7 +661,7 @@ class AppBuilder(BundleBuilder):
                 if USE_ZIPIMPORT:
                     if name != "zlib":
                         # neatly pack all extension modules in a subdirectory,
# except zlib, since it's neccesary for bootstrapping.
                         dstpath = pathjoin("ExtensionModules", dstpath)
                     # Python modules are stored in a Zip archive, but put
                     # extensions in Contents/Resources/. Add a tiny "loader"
index e09774f2d9bdfed0260456fb824cc5a1c3dee21d..3992d7bb4e6cb7c7cd410e406dc97dae8810aa56 100755 (executable)
@@ -420,7 +420,7 @@ class MailmanProxy(PureProxy):
         s = StringIO(data)
         msg = Message.Message(s)
         # These headers are required for the proper execution of Mailman.  All
# MTAs in existance seem to add these if the original message doesn't
         # have them.
         if not msg.getheader('from'):
             msg['From'] = mailfrom
index 2c228395d78a2560c13647699b1705ee77e201ee..687ef814845233701455480299737a6bd72b353b 100644 (file)
@@ -1775,7 +1775,7 @@ class TarFile(object):
     def getmember(self, name):
         """Return a TarInfo object for member `name'. If `name' can not be
            found in the archive, KeyError is raised. If a member occurs more
than once in the archive, its last occurence is assumed to be the
            most up-to-date version.
         """
         tarinfo = self._getmember(name)
index 75eaebded14c3dca7a50b4b4ba76d62cc84da862..fad517c3f5efa6e92b3aee29c8d676b967dcdbb6 100644 (file)
@@ -170,7 +170,7 @@ result_2004_html = """
 
 class OutputTestCase(unittest.TestCase):
     def normalize_calendar(self, s):
-        # Filters out locale dependant strings
+        # Filters out locale dependent strings
         def neitherspacenordigit(c):
             return not c.isspace() and not c.isdigit()
 
index 173f40fa066f182a728a73c7dc3b77ba2840cb71..a0d80513d5190dcac8859d178ca3166d622f3bd0 100644 (file)
@@ -87,11 +87,11 @@ class TestCaseBase(unittest.TestCase):
         # Make sure the right things happen for remove_option();
         # added to include check for SourceForge bug #123324:
         self.failUnless(cf.remove_option('Foo Bar', 'foo'),
-                        "remove_option() failed to report existance of option")
+                        "remove_option() failed to report existence of option")
         self.failIf(cf.has_option('Foo Bar', 'foo'),
                     "remove_option() failed to remove option")
         self.failIf(cf.remove_option('Foo Bar', 'foo'),
-                    "remove_option() failed to report non-existance of option"
+                    "remove_option() failed to report non-existence of option"
                     " that was removed")
 
         self.assertRaises(ConfigParser.NoSectionError,
@@ -264,7 +264,7 @@ class TestCaseBase(unittest.TestCase):
         file1 = test_support.findfile("cfgparser.1")
         # check when we pass a mix of readable and non-readable files:
         cf = self.newconfig()
-        parsed_files = cf.read([file1, "nonexistant-file"])
+        parsed_files = cf.read([file1, "nonexistent-file"])
         self.assertEqual(parsed_files, [file1])
         self.assertEqual(cf.get("Foo Bar", "foo"), "newbar")
         # check when we pass only a filename:
@@ -274,7 +274,7 @@ class TestCaseBase(unittest.TestCase):
         self.assertEqual(cf.get("Foo Bar", "foo"), "newbar")
         # check when we pass only missing files:
         cf = self.newconfig()
-        parsed_files = cf.read(["nonexistant-file"])
+        parsed_files = cf.read(["nonexistent-file"])
         self.assertEqual(parsed_files, [])
         # check when we pass no files:
         cf = self.newconfig()
index 656551d7c0fecfeff95bd2732e0d315412809784..a37a3262c0920ca3dace149cc21d897de89cd143 100644 (file)
@@ -109,7 +109,7 @@ class CodecCallbackTest(unittest.TestCase):
         # useful that the error handler is not called for every single
         # unencodable character, but for a complete sequence of
         # unencodable characters, otherwise we would output many
-        # unneccessary escape sequences.
+        # unnecessary escape sequences.
 
         def uninamereplace(exc):
             if not isinstance(exc, UnicodeEncodeError):
index 66f9a83041fd72896a4f685e5b6f22998ad0519f..93d62f784c97542426e5ba9d6a555e5a79073f77 100644 (file)
@@ -1714,7 +1714,7 @@ class LWPCookieTests(TestCase):
             counter[key] = counter[key] + 1
 
         self.assert_(not (
-            # a permanent cookie got lost accidently
+            # a permanent cookie got lost accidentally
             counter["perm_after"] != counter["perm_before"] or
             # a session cookie hasn't been cleared
             counter["session_after"] != 0 or
index 8088819519ccef32384dc72cabdca711631fecbb..c455e6b7106cfa4f5a0e9844302756028f6b6868 100644 (file)
@@ -54,7 +54,7 @@ Here's the new type at work:
     {1: 3.25}
     >>> print a[1]                      # show the new item
     3.25
-    >>> print a[0]                      # a non-existant item
+    >>> print a[0]                      # a non-existent item
     0.0
     >>> a.merge({1:100, 2:200})         # use a dict method
     >>> print sortdict(a)               # show the result
index e245d5974f5cfceb00d5decf77b295ac7bfb8d9c..f374c8d628790227bcd56fc834db97672c2019b7 100644 (file)
@@ -196,7 +196,7 @@ class ArbitraryFunctionAttrTest(FuncAttrsTest):
 
     def test_unset_attr(self):
         for func in [self.b, self.f.a, self.fi.a]:
-            try:  func.non_existant_attr
+            try:  func.non_existent_attr
             except AttributeError: pass
             else: self.fail("using unknown attributes should raise "
                             "AttributeError")
index 3d01b31de7558d45f2210ec6cc3b147cbd9184d6..b4e6ae5e7708104438ed9d86bcb9b77318720356 100644 (file)
@@ -104,7 +104,7 @@ class OtherNetworkTests(unittest.TestCase):
     def test_ftp(self):
         urls = [
             'ftp://ftp.kernel.org/pub/linux/kernel/README',
-            'ftp://ftp.kernel.org/pub/linux/kernel/non-existant-file',
+            'ftp://ftp.kernel.org/pub/linux/kernel/non-existent-file',
             #'ftp://ftp.kernel.org/pub/leenox/kernel/test',
             'ftp://gatekeeper.research.compaq.com/pub/DEC/SRC'
                 '/research-reports/00README-Legal-Rules-Regs',
index 3169acfb6b3c41822b031494493653c2efb483da..02fd6a0ad6a6a96656d8494d57e7cace10b10a1f 100644 (file)
@@ -8,7 +8,7 @@ written by Barry Warsaw.
 from types import ListType, TupleType
 
 # Regular expression that matches `special' characters in parameters, the
# existance of which force quoting of the parameter value.
 import re
 tspecials = re.compile(r'[ \(\)<>@,;:\\"/\[\]\?=]')
 
index 613d501d459eaf0024d18f0348fde2a9a4a7dcff..d928f53e84464c75c6e93af14704f98ddc62b88a 100644 (file)
@@ -22,7 +22,7 @@ Date: Wed, 6 Aug 1997 11:41:00 +0200 (EET)
 (2) Stefan Esser (se@MI.Uni-Koeln.DE), in work done to compile Python
     1.0.0 on AIX 3.2.4, reports that AIX compilers don't like the LANG
     environment varaiable set to European locales.  This makes the compiler
-    generate floating point constants using "," as the decimal seperator,
+    generate floating point constants using "," as the decimal separator,
     which the assembler doesn't understand (or perhaps it is the other way
     around, with the assembler expecting, but not getting "," in float
     numbers).  "LANG=C; export LANG" solves the problem, as does
index ef33b26515a1a0b1a1d8ac745f9b33716070843c..14f283d92d75fbb196d185c3f04a76cc91cd7e65 100644 (file)
@@ -9862,7 +9862,7 @@ Tue Apr  6 19:38:18 1999  Guido van Rossum  <guido@eric.cnri.reston.va.us>
        Also (quite separately, but strangely related to the philosophical
        issue above) fix abspath() so that if win32api exists, it doesn't fail
        when the path doesn't actually exist -- if GetFullPathName() fails,
-       fall back on the old strategy (join with getcwd() if neccessary, and
+       fall back on the old strategy (join with getcwd() if necessary, and
        then use normpath()).
 
        * configure.in, configure, config.h.in, acconfig.h:
@@ -1374,7 +1374,7 @@ class TextIOWrapper(TextIOBase):
     or '\r\n' are translated to '\n' before being returned to the
     caller. Conversely, on output, '\n' is translated to the system
-    default line seperator, os.linesep. If newline is any other of its
+    default line separator, os.linesep. If newline is any other of its
     legal values, that newline becomes the newline when the file is read
     and it is returned untranslated. On output, '\n' is converted to the
@@ -661,7 +661,7 @@ class AppBuilder(BundleBuilder):
                     if name != "zlib":
                         # neatly pack all extension modules in a subdirectory,
-                        # except zlib, since it's neccesary for bootstrapping.
+                        # except zlib, since it's necessary for bootstrapping.
                         dstpath = pathjoin("ExtensionModules", dstpath)
                     # Python modules are stored in a Zip archive, but put
@@ -420,7 +420,7 @@ class MailmanProxy(PureProxy):
         msg = Message.Message(s)
         # These headers are required for the proper execution of Mailman.  All
-        # MTAs in existance seem to add these if the original message doesn't
+        # MTAs in existence seem to add these if the original message doesn't
         # have them.
         if not msg.getheader('from'):
@@ -1775,7 +1775,7 @@ class TarFile(object):
         """Return a TarInfo object for member `name'. If `name' can not be
            found in the archive, KeyError is raised. If a member occurs more
-           than once in the archive, its last occurence is assumed to be the
+           than once in the archive, its last occurrence is assumed to be the
            most up-to-date version.
         """
@@ -8,7 +8,7 @@ written by Barry Warsaw.
 
 # Regular expression that matches `special' characters in parameters, the
-# existance of which force quoting of the parameter value.
+# existence of which force quoting of the parameter value.
 import re
 tspecials = re.compile(r'[ \(\)<>@,;:\\"/\[\]\?=]')
index 1ba1a73983d8f89252f7742ef17a28c6b117519a..7b869b56acfd1e263730096e2c261a31297eba05 100644 (file)